==> eloquentarduino-0.0.36.tar.gz: eloquentarduino-0.0.36/eloquentarduino/ml/classification/tensorflow/gridsearch/LayerProxy.py <==
from itertools import product
from tensorflow.keras import layers


class LayerProxy:
    """
    Proxy for Tensorflow Keras layers
    """
    def __init__(self, layer_type, *args, **kwargs):
        self.type = layer_type
        self.args = args
        self.kwargs = kwargs

    def __str__(self):
        """
        Convert to string
        """
        return '%s(%s, %s)' % (self.type, self.args, self.kwargs)

    def __repr__(self):
        """
        Convert to string
        """
        return str(self)

    def __getstate__(self):
        """
        Get state for copy
        """
        return self.__dict__

    def __setstate__(self, state):
        """
        Set state from copy
        """
        self.__dict__ = state

    def __getattr__(self, layer_type):
        """
        Make the LayerProxy object to behave as a layer factory
        """
        assert hasattr(layers, layer_type), 'unknown layer %s' % layer_type

        return LayerProxy(layer_type)

    def __call__(self, *args, **kwargs):
        """
        Allow the proxy to be configured as if it was a "normal" keras layer
        """
        self.args = args
        self.kwargs = kwargs

        return self

    def enumerate(self):
        """
        List all the combinations for the hyperparameters
        :return: generator of configured layers
        """
        fixed_parameters = {k: v for k, v in self.kwargs.items() if not k.startswith('hyper_')}
        hyper_parameters = {k.replace('hyper_', ''): v for k, v in self.kwargs.items() if k.startswith('hyper_')}

        if len(hyper_parameters) == 0:
            yield LayerProxy(self.type, *self.args, **fixed_parameters)
            return

        for hyper_values in product(*hyper_parameters.values()):
            hyper_combination = {k: v for k, v in zip(hyper_parameters.keys(), hyper_values)}
            hyper_combination.update(fixed_parameters)

            yield LayerProxy(self.type, *self.args, **hyper_combination)

    def instantiate(self):
        """
        Instantiate Keras layer
        """
        return getattr(layers, self.type)(*self.args, **self.kwargs)

==> eloquentarduino-0.0.37.tar.gz: eloquentarduino-0.0.37/eloquentarduino/ml/classification/tensorflow/gridsearch/LayerProxy.py <==
from itertools import product
from tensorflow.keras import layers


class LayerProxy:
    """
    Proxy for Tensorflow Keras layers
    """
    def __init__(self, layer_type, *args, **kwargs):
        self.type = layer_type
        self.args = args
        self.kwargs = kwargs

    def __str__(self):
        """
        Convert to string
        """
        return '%s(%s, %s)' % (self.type, self.args, self.kwargs)

    def __repr__(self):
        """
        Convert to string
        """
        return str(self)

    def __getstate__(self):
        """
        Get state for copy
        """
        return self.__dict__

    def __setstate__(self, state):
        """
        Set state from copy
        """
        self.__dict__ = state

    def __getattr__(self, layer_type):
        """
        Make the LayerProxy object to behave as a layer factory
        """
        assert hasattr(layers, layer_type), 'unknown layer %s' % layer_type

        return LayerProxy(layer_type)

    def __call__(self, *args, **kwargs):
        """
        Allow the proxy to be configured as if it was a "normal" keras layer
        """
        self.args = args
        self.kwargs = kwargs

        return self

    @property
    def tf_type(self):
        return getattr(layers, self.type)

    def enumerate(self):
        """
        List all the combinations for the hyperparameters
        :return: generator of configured layers
        """
        fixed_parameters = {k: v for k, v in self.kwargs.items() if not k.startswith('hyper_')}
        hyper_parameters = {k.replace('hyper_', ''): v for k, v in self.kwargs.items() if k.startswith('hyper_')}

        if len(hyper_parameters) == 0:
            yield LayerProxy(self.type, *self.args, **fixed_parameters)
            return

        for hyper_values in product(*hyper_parameters.values()):
            hyper_combination = {k: v for k, v in zip(hyper_parameters.keys(), hyper_values)}
            hyper_combination.update(fixed_parameters)

            yield LayerProxy(self.type, *self.args, **hyper_combination)

    def instantiate(self):
        """
        Instantiate Keras layer
        """
        return self.tf_type(*self.args, **self.kwargs)
